@@ -1,5 +1,4 @@
-MISSING_DATA = 'https://metadata.datadrivendiscovery.org/types/' + \
-               'MissingData'
+MISSING_DATA = 'https://metadata.datadrivendiscovery.org/types/MissingData'
 INTEGER = 'http://schema.org/Integer'
 FLOAT = 'http://schema.org/Float'
 TEXT = 'http://schema.org/Text'
@@ -8,7 +7,8 @@ LATITUDE = 'http://schema.org/latitude'
 LONGITUDE = 'http://schema.org/longitude'
 DATE_TIME = 'http://schema.org/DateTime'
 ADDRESS = 'http://schema.org/address'
-PHONE_NUMBER = 'https://metadata.datadrivendiscovery.org/types/' + \
-               'PhoneNumber'
+ADMIN = 'http://schema.org/AdministrativeArea'
 ID = 'http://schema.org/identifier'
 CATEGORICAL = 'http://schema.org/Enumeration'
+GEO_POINT = 'http://schema.org/GeoCoordinates'
+GEO_POLYGON = 'http://schema.org/GeoShape'
